[![Build Status](https://travis-ci.org/localmed/pyserializer.svg?branch=development)](https://travis-ci.org/localmed/pyserializer) [![Documentation Status](https://readthedocs.org/projects/pyserializer/badge/?version=latest)](http://pyserializer.readthedocs.org/en/latest/?badge=latest)


pyserializer
============

`pyserializer` is a simple python serialization/deserialization library. It is an ORM agnostic library for converting python objects to native Python datatypes, and vice versa. Click [here](http://pyserializer.readthedocs.org/en/latest/) for documentation.

Installation
------------

You can to use [pip](https://pypi.python.org/pypi/pip) to install pyserializer:
``` bash
$ pip install pyserializer
```
Or using last source:
``` bash
$ pip install git+git://github.com/localmed/pyserializer.git
```

Documentation
-------------
For full documentation and examples see (http://pyserializer.readthedocs.org/en/latest/).

Offline Documentation
---------------------

Download the docs in [pdf](https://media.readthedocs.org/pdf/pyserializer/latest/pyserializer.pdf)
or [epub](https://readthedocs.org/projects/pyserializer/downloads/epub/latest/)
formats for offline reading.

Feature Requests and Bug Reports
--------------------------------

Should all be reported on the Github Issue Tracker


Contribution
------------

[Contribution](CONTRIBUTING.md)


Copyright
---------

Copyright (c) 2016 [LocalMed, Inc.](http://www.localmed.com/). See LICENSE for details.

